// Copyright 2022 The CCGO Authors. All rights reserved.
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.

package ccgo // import "modernc.org/ccgo/v4/lib"

var testExecKnownFails = map[string]struct{}{
	// ==== EXEC FAIL - compiles and builds but fails when executed.

	`assets/benchmarksgame-team.pages.debian.net/fasta-2.c`:                              {}, // EXEC FAIL: "assets/benchmarksgame-team.pages.debian.net/fasta-2.c: libc_darwin.go:1669:Xfputs: TODOTODO "
	`assets/benchmarksgame-team.pages.debian.net/fasta-5.c`:                              {}, // EXEC FAIL: "assets/benchmarksgame-team.pages.debian.net/fasta-5.c: libc_darwin.go:1669:Xfputs: TODOTODO "
	`assets/benchmarksgame-team.pages.debian.net/fasta-6.c`:                              {}, // EXEC FAIL: "assets/benchmarksgame-team.pages.debian.net/fasta-6.c: libc_darwin.go:1669:Xfputs: TODOTODO "
	`assets/benchmarksgame-team.pages.debian.net/fasta-7.c`:                              {}, // EXEC FAIL: "assets/benchmarksgame-team.pages.debian.net/fasta-7.c: libc_darwin.go:1669:Xfputs: TODOTODO "
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/20101011-1.c`:                  {}, // EXEC FAIL: "assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/20101011-1.c: panic: runtime error: integer divide by zero"
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/align-3.c`:                     {}, // EXEC FAIL: "assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/align-3.c: : FAIL: signal: abort trap (.:0:: .:0:: asm_amd64.s:1650:goexit: asm_amd64.s:1650:goexit: all_test.go:447:1: all_test.go:598:testExec1:)"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/20101011-1.c`:  {}, // EXEC FAIL: "assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/20101011-1.c: panic: runtime error: integer divide by zero"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/align-3.c`:     {}, // EXEC FAIL: "assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/align-3.c: : FAIL: signal: abort trap (.:0:: .:0:: asm_amd64.s:1650:goexit: asm_amd64.s:1650:goexit: all_test.go:447:1: all_test.go..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/return-addr.c`: {}, // EXEC FAIL
	`assets/github.com/vnmakarov/mir/c-benchmarks/except.c`:                              {}, // EXEC FAIL: "assets/github.com/vnmakarov/mir/c-benchmarks/except.c: libc.go:2142:Xlongjmp: TODOTODO "
	`assets/github.com/vnmakarov/mir/c-benchmarks/method-call.c`:                         {}, // EXEC FAIL: "assets/github.com/vnmakarov/mir/c-benchmarks/method-call.c: libc_darwin.go:1669:Xfputs: TODOTODO "
	`assets/github.com/vnmakarov/mir/c-tests/lacc/bitfield-basic.c`:                      {}, // EXEC FAIL
	`assets/github.com/vnmakarov/mir/c-tests/lacc/bitfield-trailing-zero.c`:              {}, // EXEC FAIL
	`assets/github.com/vnmakarov/mir/c-tests/lacc/function-implicit-declare.c`:           {}, // EXEC FAIL: "assets/github.com/vnmakarov/mir/c-tests/lacc/function-implicit-declare.c: : FAIL: exit status 42 (.:0:: .:0:: asm_amd64.s:1650:goexit: asm_amd64.s:1650:goexit: all_test.go:444:1: all_test.go:587:testE..."
	`assets/github.com/vnmakarov/mir/c-tests/lacc/long-double-load.c`:                    {}, // EXEC FAIL
	`assets/github.com/vnmakarov/mir/c-tests/lacc/vararg-complex-2.c`:                    {}, // EXEC FAIL: "assets/github.com/vnmakarov/mir/c-tests/lacc/vararg-complex-2.c: 0,0,0,0"
	`assets/github.com/vnmakarov/mir/c-tests/new/setjmp.c`:                               {}, // EXEC FAIL: "assets/github.com/vnmakarov/mir/c-tests/new/setjmp.c: libc.go:2142:Xlongjmp: TODOTODO "
	`assets/github.com/vnmakarov/mir/c-tests/new/setjmp2.c`:                              {}, // EXEC FAIL: "assets/github.com/vnmakarov/mir/c-tests/new/setjmp2.c: libc.go:2142:Xlongjmp: TODOTODO "
	`assets/tcc-0.9.27/tests/tests2/94_generic.c`:                                        {}, // EXEC FAIL

	// ==== BUILD FAIL - compiles but does not build.

	`assets/benchmarksgame-team.pages.debian.net/reverse-complement-4.c`: {}, // BUILD FAIL: "exit status 1"
	`assets/ccgo/bug/sqlite.c`: {}, // BUILD FAIL: "exit status 1"
	`assets/ccgo/bug/union3.c`: {}, // BUILD FAIL: "exit status 1"
	`assets/ccgo/bug/union4.c`: {}, // BUILD FAIL: "exit status 1"
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/20010122-1.c`:                        {}, // BUILD FAIL: "exit status 1"
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/20030323-1.c`:                        {}, // BUILD FAIL: "exit status 1"
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/20030811-1.c`:                        {}, // BUILD FAIL: "exit status 1"
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/20040709-1.c`:                        {}, // BUILD FAIL: "exit status 1"
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/20040709-2.c`:                        {}, // BUILD FAIL: "exit status 1"
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/20040709-3.c`:                        {}, // BUILD FAIL: "exit status 1"
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/20060905-1.c`:                        {}, // BUILD FAIL: "exit status 1"
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/20070614-1.c`:                        {}, // BUILD FAIL: "exit status 1"
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/20080502-1.c`:                        {}, // BUILD FAIL: "exit status 1"
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/20090113-2.c`:                        {}, // BUILD FAIL: "exit status 1"
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/20090113-3.c`:                        {}, // BUILD FAIL: "exit status 1"
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/20180921-1.c`:                        {}, // BUILD FAIL: "exit status 1"
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/built-in-setjmp.c`:                   {}, // BUILD FAIL: "exit status 1"
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/builtin-bitops-1.c`:                  {}, // BUILD FAIL: "exit status 1"
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/ieee/20010114-2.c`:                   {}, // BUILD FAIL: "exit status 1"
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/ieee/20030331-1.c`:                   {}, // BUILD FAIL: "exit status 1"
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/ieee/compare-fp-1.c`:                 {}, // BUILD FAIL: "exit status 1"
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr19449.c`:                           {}, // BUILD FAIL: "exit status 1"
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr35456.c`:                           {}, // BUILD FAIL: "exit status 1"
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr37780.c`:                           {}, // BUILD FAIL: "exit status 1"
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr42570.c`:                           {}, // BUILD FAIL: "exit status 1"
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr53160.c`:                           {}, // BUILD FAIL: "exit status 1"
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr60003.c`:                           {}, // BUILD FAIL: "exit status 1"
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr66556.c`:                           {}, // BUILD FAIL: "exit status 1"
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr67037.c`:                           {}, // BUILD FAIL: "exit status 1"
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr71631.c`:                           {}, // BUILD FAIL: "exit status 1"
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr79286.c`:                           {}, // BUILD FAIL: "exit status 1"
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr89195.c`:                           {}, // BUILD FAIL: "exit status 1"
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/strlen-6.c`:                          {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/20010122-1.c`:        {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/20030323-1.c`:        {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/20030811-1.c`:        {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/20040709-1.c`:        {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/20040709-2.c`:        {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/20040709-3.c`:        {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/20060905-1.c`:        {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/20070614-1.c`:        {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/20080502-1.c`:        {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/20090113-2.c`:        {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/20090113-3.c`:        {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/20180921-1.c`:        {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/built-in-setjmp.c`:   {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/builtin-bitops-1.c`:  {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/ieee/20010114-2.c`:   {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/ieee/20030331-1.c`:   {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/ieee/compare-fp-1.c`: {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr19449.c`:           {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr35456.c`:           {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr37780.c`:           {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr42570.c`:           {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr53160.c`:           {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr60003.c`:           {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr64242.c`:           {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr66556.c`:           {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr67037.c`:           {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr71631.c`:           {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr79286.c`:           {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr84521.c`:           {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr89195.c`:           {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr93249.c`:           {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr93494.c`:           {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr94134.c`:           {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/strlen-6.c`:          {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/vnmakarov/mir/c-tests/andrewchambers_c/0010-goto1.c`:                    {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/vnmakarov/mir/c-tests/andrewchambers_c/0011-switch1.c`:                  {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/vnmakarov/mir/c-tests/andrewchambers_c/0028-inits14.c`:                  {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/vnmakarov/mir/c-tests/andrewchambers_c/0028-inits15.c`:                  {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/vnmakarov/mir/c-tests/lacc/goto.c`:                                      {}, // BUILD FAIL: "exit status 1"
	`assets/github.com/vnmakarov/mir/c-tests/new/var-size-in-var-initializer.c`:                {}, // BUILD FAIL: "exit status 1"
	`assets/tcc-0.9.27/tests/tests2/81_types.c`:                                                {}, // BUILD FAIL: "exit status 1"

	// ==== COMPILE FAIL - does not compile.

	`assets/benchmarksgame-team.pages.debian.net/mandelbrot-3.c`:                            {}, // COMPILE FAIL: "\"mandelbrot-3.c:27:21: unsupported vector type: v2df (expr.go:524:expr0: expr.go:3817:primaryExpression: expr.go:4273:primaryExpressionFloatConst: type.go:60:verifyTyp: type.go:65:typ0: type.go:455:is..."
	`assets/benchmarksgame-team.pages.debian.net/mandelbrot-4.c`:                            {}, // COMPILE FAIL: "\"mandelbrot-4.c:19:21: unsupported vector type: v2df (expr.go:524:expr0: expr.go:3817:primaryExpression: expr.go:4273:primaryExpressionFloatConst: type.go:60:verifyTyp: type.go:65:typ0: type.go:455:is..."
	`assets/benchmarksgame-team.pages.debian.net/mandelbrot-8.c`:                            {}, // COMPILE FAIL: "\"mandelbrot-8.c:16:30: unsupported vector type: Vec (expr.go:1198:checkVolatileExpr: expr.go:101:expr: expr.go:530:expr0: expr.go:1682:unaryExpression: type.go:422:isValidType: type.go:455:isValidType..."
	`assets/benchmarksgame-team.pages.debian.net/mandelbrot.c`:                              {}, // COMPILE FAIL: "\"mandelbrot.c:23:15: unsupported vector type: v2df (expr.go:524:expr0: expr.go:3817:primaryExpression: expr.go:4273:primaryExpressionFloatConst: type.go:60:verifyTyp: type.go:65:typ0: type.go:455:isVa..."
	`assets/benchmarksgame-team.pages.debian.net/nbody-4.c`:                                 {}, // COMPILE FAIL: "\"/Library/Developer/CommandLineTools/usr/lib/clang/15.0.0/include/avx512fp16intrin.h:104:52: unexpected '(', expected postfix expression\""
	`assets/benchmarksgame-team.pages.debian.net/nbody-5.c`:                                 {}, // COMPILE FAIL: "\"nbody-5.c:22:1: unsupported vector type: v2df (decl.go:596:declaration: type.go:574:defineStructType: type.go:509:structLiteral: type.go:263:typ0: type.go:65:typ0: type.go:455:isValidType1:)\""
	`assets/benchmarksgame-team.pages.debian.net/nbody-8.c`:                                 {}, // COMPILE FAIL: "\"/Library/Developer/CommandLineTools/usr/lib/clang/15.0.0/include/avx512fp16intrin.h:104:52: unexpected '(', expected postfix expression\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/20000326-2.c`:                     {}, // COMPILE FAIL: "\"20000326-2.c:7:3: label declarations not supported (compile.go:433:compile: decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:352:functionDefinition0: stmt.go:324:compoundState..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/20000405-3.c`:                     {}, // COMPILE FAIL: "\"20000405-3.c:1:1: unsupported alignment 32 of struct foo {entry array of 40 pointer to void} (decl.go:296:externalDeclaration: decl.go:596:declaration: type.go:574:defineStructType: type.go:509:struc..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/20000518-1.c`:                     {}, // COMPILE FAIL: "\"20000518-1.c:7:2: label declarations not supported (compile.go:433:compile: decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:352:functionDefinition0: stmt.go:324:compoundState..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/20010202-1.c`:                     {}, // COMPILE FAIL: "\"20010202-1.c:3:5: incomplete type: array of array of char (decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:342:functionDefinition0: type.go:474:isValidType1: type.go:398:isVa..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/20021108-1.c`:                     {}, // COMPILE FAIL: "\"TODO UnaryExpressionLabelAddr (expr.go:1178:additiveExpression: expr.go:1193:binopArgs: expr.go:1198:checkVolatileExpr: expr.go:101:expr: expr.go:530:expr0: expr.go:1691:unaryExpression:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/20030903-1.c`:                     {}, // COMPILE FAIL: "\"TODO UnaryExpressionReal (expr.go:101:expr: expr.go:494:expr0: expr.go:3439:assignmentExpression: expr.go:101:expr: expr.go:530:expr0: expr.go:1717:unaryExpression:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/20030910-1.c`:                     {}, // COMPILE FAIL: "\"TODO UnaryExpressionReal (expr.go:101:expr: expr.go:494:expr0: expr.go:3444:assignmentExpression: expr.go:101:expr: expr.go:530:expr0: expr.go:1717:unaryExpression:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/20040317-1.c`:                     {}, // COMPILE FAIL: "\"20040317-1.c:1:5: incomplete type: array of array of char (decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:342:functionDefinition0: type.go:474:isValidType1: type.go:398:isVa..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/20040614-1.c`:                     {}, // COMPILE FAIL: "\"TODO <nil> (asm_amd64.s:1650:goexit: compile.go:433:compile: decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:344:functionDefinition0: decl.go:101:newFnCtx:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/20070603-1.c`:                     {}, // COMPILE FAIL: "\"TODO UnaryExpressionReal (expr.go:1161:additiveExpression: expr.go:1193:binopArgs: expr.go:1198:checkVolatileExpr: expr.go:101:expr: expr.go:530:expr0: expr.go:1717:unaryExpression:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/20070603-2.c`:                     {}, // COMPILE FAIL: "\"TODO UnaryExpressionReal (expr.go:1161:additiveExpression: expr.go:1193:binopArgs: expr.go:1198:checkVolatileExpr: expr.go:101:expr: expr.go:530:expr0: expr.go:1717:unaryExpression:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/20070919-1.c`:                     {}, // COMPILE FAIL: "\"TODO exprUintptr (expr.go:101:expr: expr.go:530:expr0: expr.go:1605:unaryExpression: expr.go:101:expr: expr.go:522:expr0: expr.go:2096:postfixExpression:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/20110131-1.c`:                     {}, // COMPILE FAIL: "\"-: TODO (expr.go:1198:checkVolatileExpr: expr.go:101:expr: expr.go:506:expr0: expr.go:914:conditionalExpression: expr.go:70:topExpr: expr.go:85:expr:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/20121107-1.c`:                     {}, // COMPILE FAIL: "\"-: TODO (expr.go:524:expr0: expr.go:3834:primaryExpression: expr.go:506:expr0: expr.go:914:conditionalExpression: expr.go:70:topExpr: expr.go:85:expr:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/920301-1.c`:                       {}, // COMPILE FAIL: "\"TODO UnaryExpressionLabelAddr (init.go:263:initializerArray: init.go:93:initializer: expr.go:70:topExpr: expr.go:101:expr: expr.go:530:expr0: expr.go:1691:unaryExpression:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/920428-3.c`:                       {}, // COMPILE FAIL: "\"TODO <nil> (asm_amd64.s:1650:goexit: compile.go:433:compile: decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:344:functionDefinition0: decl.go:101:newFnCtx:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/920501-1.c`:                       {}, // COMPILE FAIL: "\"TODO UnaryExpressionLabelAddr (init.go:263:initializerArray: init.go:93:initializer: expr.go:70:topExpr: expr.go:101:expr: expr.go:530:expr0: expr.go:1691:unaryExpression:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/920501-7.c`:                       {}, // COMPILE FAIL: "\"TODO <nil> (asm_amd64.s:1650:goexit: compile.go:433:compile: decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:344:functionDefinition0: decl.go:101:newFnCtx:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/950610-1.c`:                       {}, // COMPILE FAIL: "\"950610-1.c:1:1: incomplete type: array of array of int (decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:342:functionDefinition0: type.go:474:isValidType1: type.go:398:isValid..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/950613-1.c`:                       {}, // COMPILE FAIL: "\"TODO <nil> (asm_amd64.s:1650:goexit: compile.go:433:compile: decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:344:functionDefinition0: decl.go:101:newFnCtx:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/981001-4.c`:                       {}, // COMPILE FAIL: "\"-: TODO (expr.go:524:expr0: expr.go:3834:primaryExpression: expr.go:506:expr0: expr.go:914:conditionalExpression: expr.go:70:topExpr: expr.go:85:expr:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/981006-1.c`:                       {}, // COMPILE FAIL: "\"981006-1.c:14:3: label declarations not supported (compile.go:433:compile: decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:352:functionDefinition0: stmt.go:324:compoundStatem..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/981223-1.c`:                       {}, // COMPILE FAIL: "\"TODO UnaryExpressionReal (expr.go:1266:equalityExpression: expr.go:1193:binopArgs: expr.go:1198:checkVolatileExpr: expr.go:101:expr: expr.go:530:expr0: expr.go:1717:unaryExpression:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/991213-1.c`:                       {}, // COMPILE FAIL: "\"TODO UnaryExpressionImag (expr.go:70:topExpr: expr.go:101:expr: expr.go:524:expr0: expr.go:3834:primaryExpression: expr.go:530:expr0: expr.go:1715:unaryExpression:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/complex-1.c`:                      {}, // COMPILE FAIL: "\"TODO *cc.PredefinedType _Complex int _Complex int (expr.go:70:topExpr: expr.go:115:expr: expr.go:169:convert: expr.go:331:convertType: type.go:30:helper: type.go:159:typ0:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/complex-2.c`:                      {}, // COMPILE FAIL: "\"TODO UnaryExpressionImag (expr.go:101:expr: expr.go:494:expr0: expr.go:3439:assignmentExpression: expr.go:101:expr: expr.go:530:expr0: expr.go:1715:unaryExpression:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/complex-3.c`:                      {}, // COMPILE FAIL: "\"TODO UnaryExpressionImag (expr.go:1161:additiveExpression: expr.go:1193:binopArgs: expr.go:1198:checkVolatileExpr: expr.go:101:expr: expr.go:530:expr0: expr.go:1715:unaryExpression:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/complex-4.c`:                      {}, // COMPILE FAIL: "\"TODO UnaryExpressionReal (expr.go:101:expr: expr.go:494:expr0: expr.go:3439:assignmentExpression: expr.go:101:expr: expr.go:530:expr0: expr.go:1717:unaryExpression:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/complex-5.c`:                      {}, // COMPILE FAIL: "\"TODO *cc.PredefinedType _Complex int _Complex int (expr.go:101:expr: expr.go:524:expr0: expr.go:3815:primaryExpression: expr.go:4252:primaryExpressionIntConst: type.go:30:helper: type.go:159:typ0:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/labels-3.c`:                       {}, // COMPILE FAIL: "\"TODO <nil> (asm_amd64.s:1650:goexit: compile.go:433:compile: decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:344:functionDefinition0: decl.go:101:newFnCtx:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pass.c`:                           {}, // COMPILE FAIL: "\"pass.c:13:10: too many arguments to function 'foo', type 'function(int, int, int) returning int' in 'foo ((int) & q, q, w, e, q, (int) &w)' (stmt.go:841:jumpStatement: expr.go:1198:checkVolatileExpr:..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pc44485.c`:                        {}, // COMPILE FAIL: "\"-: TODO (expr.go:1198:checkVolatileExpr: expr.go:101:expr: expr.go:506:expr0: expr.go:914:conditionalExpression: expr.go:70:topExpr: expr.go:85:expr:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr17913.c`:                        {}, // COMPILE FAIL: "\"TODO <nil> (asm_amd64.s:1650:goexit: compile.go:433:compile: decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:344:functionDefinition0: decl.go:101:newFnCtx:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr18903.c`:                        {}, // COMPILE FAIL: "\"TODO UnaryExpressionLabelAddr (stmt.go:360:blockItem: stmt.go:38:statement: expr.go:70:topExpr: expr.go:101:expr: expr.go:530:expr0: expr.go:1691:unaryExpression:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr21356.c`:                        {}, // COMPILE FAIL: "\"TODO <nil> (asm_amd64.s:1650:goexit: compile.go:433:compile: decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:344:functionDefinition0: decl.go:101:newFnCtx:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr22422.c`:                        {}, // COMPILE FAIL: "\"TODO pr22422.c:27:3: from pointer to int, exprUintptr to pointer to int exprVoid, src '&d->c [d->n]', buf '((((aad))+4)+(((ppuintptr(((*tsD)(iqunsafe.ppPointer((aad))).fdn))))*4))' (stmt.go:360:block..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr25224.c`:                        {}, // COMPILE FAIL: "\"TODO <nil> (asm_amd64.s:1650:goexit: compile.go:433:compile: decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:344:functionDefinition0: decl.go:101:newFnCtx:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr27341-1.c`:                      {}, // COMPILE FAIL: "\"TODO UnaryExpressionImag (expr.go:101:expr: expr.go:494:expr0: expr.go:3439:assignmentExpression: expr.go:101:expr: expr.go:530:expr0: expr.go:1715:unaryExpression:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr27863.c`:                        {}, // COMPILE FAIL: "\"TODO <nil> (asm_amd64.s:1650:goexit: compile.go:433:compile: decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:344:functionDefinition0: decl.go:101:newFnCtx:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr28489.c`:                        {}, // COMPILE FAIL: "\"TODO <nil> (asm_amd64.s:1650:goexit: compile.go:433:compile: decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:344:functionDefinition0: decl.go:101:newFnCtx:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr29128.c`:                        {}, // COMPILE FAIL: "\"TODO <nil> (asm_amd64.s:1650:goexit: compile.go:433:compile: decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:344:functionDefinition0: decl.go:101:newFnCtx:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr33382.c`:                        {}, // COMPILE FAIL: "\"-: TODO (expr.go:524:expr0: expr.go:3834:primaryExpression: expr.go:506:expr0: expr.go:914:conditionalExpression: expr.go:70:topExpr: expr.go:85:expr:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr34334.c`:                        {}, // COMPILE FAIL: "\"TODO (compile.go:433:compile: decl.go:296:externalDeclaration: decl.go:606:declaration: decl.go:745:initDeclarator: type.go:18:typedef: type.go:325:typ0:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr35431.c`:                        {}, // COMPILE FAIL: "\"TODO *cc.PredefinedType _Complex int _Complex int (expr.go:101:expr: expr.go:524:expr0: expr.go:3815:primaryExpression: expr.go:4252:primaryExpressionIntConst: type.go:30:helper: type.go:159:typ0:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr38771.c`:                        {}, // COMPILE FAIL: "\"-: TODO (expr.go:524:expr0: expr.go:3834:primaryExpression: expr.go:506:expr0: expr.go:914:conditionalExpression: expr.go:70:topExpr: expr.go:85:expr:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr40233.c`:                        {}, // COMPILE FAIL: "\"pr40233.c:2:1: unsupported alignment 64 of struct Frame {i aligned} (decl.go:296:externalDeclaration: decl.go:596:declaration: type.go:574:defineStructType: type.go:509:structLiteral: type.go:65:typ0..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr41987.c`:                        {}, // COMPILE FAIL: "\"TODO *cc.PredefinedType _Complex char _Complex char (expr.go:101:expr: expr.go:524:expr0: expr.go:3815:primaryExpression: expr.go:4252:primaryExpressionIntConst: type.go:30:helper: type.go:159:typ0:)..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr42196-1.c`:                      {}, // COMPILE FAIL: "\"TODO *cc.PredefinedType _Complex int _Complex int (decl.go:296:externalDeclaration: decl.go:598:declaration: type.go:593:defineUnionType: type.go:503:unionLiteral: type.go:322:typ0: type.go:159:typ0:..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr42196-2.c`:                      {}, // COMPILE FAIL: "\"TODO *cc.PredefinedType _Complex int _Complex int (decl.go:296:externalDeclaration: decl.go:598:declaration: type.go:593:defineUnionType: type.go:503:unionLiteral: type.go:338:typ0: type.go:159:typ0:..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr42196-3.c`:                      {}, // COMPILE FAIL: "\"TODO *cc.PredefinedType _Complex int _Complex int (decl.go:296:externalDeclaration: decl.go:598:declaration: type.go:593:defineUnionType: type.go:503:unionLiteral: type.go:338:typ0: type.go:159:typ0:..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr42559.c`:                        {}, // COMPILE FAIL: "\"TODO UnaryExpressionLabelAddr (init.go:32:initializerOuter: init.go:93:initializer: expr.go:70:topExpr: expr.go:101:expr: expr.go:530:expr0: expr.go:1691:unaryExpression:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr42716.c`:                        {}, // COMPILE FAIL: "\"-: TODO (expr.go:1198:checkVolatileExpr: expr.go:101:expr: expr.go:506:expr0: expr.go:914:conditionalExpression: expr.go:70:topExpr: expr.go:85:expr:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr42717.c`:                        {}, // COMPILE FAIL: "\"-: TODO (expr.go:1198:checkVolatileExpr: expr.go:101:expr: expr.go:506:expr0: expr.go:914:conditionalExpression: expr.go:70:topExpr: expr.go:85:expr:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr44119.c`:                        {}, // COMPILE FAIL: "\"-: TODO (expr.go:1198:checkVolatileExpr: expr.go:101:expr: expr.go:506:expr0: expr.go:914:conditionalExpression: expr.go:70:topExpr: expr.go:85:expr:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr46107.c`:                        {}, // COMPILE FAIL: "\"TODO <nil> (asm_amd64.s:1650:goexit: compile.go:433:compile: decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:344:functionDefinition0: decl.go:101:newFnCtx:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr48641.c`:                        {}, // COMPILE FAIL: "\"TODO \\\"(X__builtin_modfl(cgtls, (iqlibc.ppFloat64FromFloat64(1.5)), cgbp) != (*(*ppfloat64)(iqunsafe.ppPointer(cgbp))))\\\" int exprBool -> long double exprDefault (expr.go:508:expr0: expr.go:1269:equa..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr51354.c`:                        {}, // COMPILE FAIL: "\"pr51354.c:15:6: unsupported alignment 32 of ai (decl.go:383:functionDefinition0: stmt.go:261:compoundStatement: decl.go:226:declareLocals: type.go:42:typ: type.go:65:typ0: type.go:441:isValidType1:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr51495.c`:                        {}, // COMPILE FAIL: "\"TODO <nil> (asm_amd64.s:1650:goexit: compile.go:433:compile: decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:344:functionDefinition0: decl.go:101:newFnCtx:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr56571.c`:                        {}, // COMPILE FAIL: "\"-: TODO (expr.go:524:expr0: expr.go:3834:primaryExpression: expr.go:506:expr0: expr.go:914:conditionalExpression: expr.go:70:topExpr: expr.go:85:expr:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr70190.c`:                        {}, // COMPILE FAIL: "\"TODO <nil> (asm_amd64.s:1650:goexit: compile.go:433:compile: decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:344:functionDefinition0: decl.go:101:newFnCtx:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr70199.c`:                        {}, // COMPILE FAIL: "\"TODO <nil> (asm_amd64.s:1650:goexit: compile.go:433:compile: decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:344:functionDefinition0: decl.go:101:newFnCtx:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr70916.c`:                        {}, // COMPILE FAIL: "\"-: TODO (expr.go:3444:assignmentExpression: expr.go:101:expr: expr.go:506:expr0: expr.go:914:conditionalExpression: expr.go:70:topExpr: expr.go:85:expr:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr71109.c`:                        {}, // COMPILE FAIL: "\"pr71109.c:15:7: too few arguments to function 'foo', type 'function(int, struct S, struct T)' in 'foo (bar, a)' (stmt.go:38:statement: expr.go:70:topExpr: expr.go:101:expr: expr.go:522:expr0: expr.go..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr77754-1.c`:                      {}, // COMPILE FAIL: "\"pr77754-1.c:5:13: incomplete type: array of array of int (asm_amd64.s:1650:goexit: asm_amd64.s:1650:goexit: compile.go:481:compile: decl.go:531:signature: type.go:398:isValidParamType: type.go:486:is..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr77754-2.c`:                      {}, // COMPILE FAIL: "\"pr77754-2.c:5:6: incomplete type: array of array of int (type.go:673:defineType0: type.go:673:defineType0: type.go:661:defineType0: type.go:474:isValidType1: type.go:398:isValidParamType: type.go:486..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr77754-3.c`:                      {}, // COMPILE FAIL: "\"pr77754-3.c:5:14: incomplete type: array of array of int (type.go:657:defineType: type.go:673:defineType0: type.go:661:defineType0: type.go:474:isValidType1: type.go:398:isValidParamType: type.go:486..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr77754-4.c`:                      {}, // COMPILE FAIL: "\"pr77754-4.c:5:14: incomplete type: array of array of int (type.go:657:defineType: type.go:673:defineType0: type.go:661:defineType0: type.go:474:isValidType1: type.go:398:isValidParamType: type.go:486..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr77754-5.c`:                      {}, // COMPILE FAIL: "\"pr77754-5.c:6:6: incomplete type: array of array of int (decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:342:functionDefinition0: type.go:474:isValidType1: type.go:398:isVali..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr84305.c`:                        {}, // COMPILE FAIL: "\"pr84305.c:3:34: TODO (expr.go:1873:postfixExpressionIndex: expr.go:101:expr: expr.go:522:expr0: expr.go:1956:postfixExpression: expr.go:1789:postfixExpressionIndex: expr.go:1739:mul:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr84960.c`:                        {}, // COMPILE FAIL: "\"TODO <nil> (asm_amd64.s:1650:goexit: compile.go:433:compile: decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:344:functionDefinition0: decl.go:101:newFnCtx:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr85704.c`:                        {}, // COMPILE FAIL: "\"pr85704.c:9:26: TODO \\\"tsC{}\\\" struct C {c struct {}}, 0 exprDefault -> struct D {d int; e struct C; f int}, 8 exprDefault (pr85704.c:9:26:) (expr.go:522:expr0: expr.go:2206:postfixExpression: init.g..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr85945.c`:                        {}, // COMPILE FAIL: "\"pr85945.c:4:1: unsupported vector type: V (decl.go:598:declaration: type.go:593:defineUnionType: type.go:503:unionLiteral: type.go:338:typ0: type.go:65:typ0: type.go:455:isValidType1:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr86122.c`:                        {}, // COMPILE FAIL: "\"TODO *cc.PredefinedType _Complex int _Complex int (expr.go:101:expr: expr.go:524:expr0: expr.go:3815:primaryExpression: expr.go:4252:primaryExpressionIntConst: type.go:30:helper: type.go:159:typ0:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr86123.c`:                        {}, // COMPILE FAIL: "\"TODO *cc.PredefinedType _Complex unsigned _Complex unsigned (expr.go:101:expr: expr.go:524:expr0: expr.go:3815:primaryExpression: expr.go:4252:primaryExpressionIntConst: type.go:30:helper: type.go:15..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr89655.c`:                        {}, // COMPILE FAIL: "\"-: TODO (expr.go:524:expr0: expr.go:3834:primaryExpression: expr.go:506:expr0: expr.go:914:conditionalExpression: expr.go:70:topExpr: expr.go:85:expr:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/simd-6.c`:                         {}, // COMPILE FAIL: "\"simd-6.c:5:11: unsupported vector type: vec (init.go:110:initializer: init.go:193:initializerArray: type.go:42:typ: type.go:352:typ0: type.go:65:typ0: type.go:455:isValidType1:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/sra-1.c`:                          {}, // COMPILE FAIL: "\"TODO UnaryExpressionReal (expr.go:1295:relationExpression: expr.go:1193:binopArgs: expr.go:1198:checkVolatileExpr: expr.go:101:expr: expr.go:530:expr0: expr.go:1717:unaryExpression:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/struct-non-lval-2.c`:              {}, // COMPILE FAIL: "\"TODO assertion failed (expr.go:101:expr: expr.go:522:expr0: expr.go:2028:postfixExpression: expr.go:2682:postfixExpressionSelect: expr.go:115:expr: expr.go:131:convert:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/struct-non-lval-3.c`:              {}, // COMPILE FAIL: "\"TODO exprUintptr (expr.go:2682:postfixExpressionSelect: expr.go:101:expr: expr.go:524:expr0: expr.go:3834:primaryExpression: expr.go:494:expr0: expr.go:3449:assignmentExpression:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/uuarg.c`:                          {}, // COMPILE FAIL: "\"uuarg.c:4:10: too few arguments to function 'foo', type 'function(int, int, int, int, int, int, int, int, int) returning int' in 'foo ()' (expr.go:1193:binopArgs: expr.go:1198:checkVolatileExpr: expr..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/vector-1.c`:                       {}, // COMPILE FAIL: "\"vector-1.c:3:1: unsupported vector type: float (decl.go:596:declaration: type.go:574:defineStructType: type.go:509:structLiteral: type.go:263:typ0: type.go:65:typ0: type.go:455:isValidType1:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/vector-2.c`:                       {}, // COMPILE FAIL: "\"vector-2.c:3:1: unsupported vector type: float (decl.go:596:declaration: type.go:574:defineStructType: type.go:509:structLiteral: type.go:263:typ0: type.go:65:typ0: type.go:455:isValidType1:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/vector-4.c`:                       {}, // COMPILE FAIL: "\"vector-4.c:7:47: unsupported vector type: signed char (decl.go:296:externalDeclaration: decl.go:606:declaration: decl.go:775:initDeclarator: type.go:42:typ: type.go:65:typ0: type.go:455:isValidType1:..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/vector-align-1.c`:                 {}, // COMPILE FAIL: "\"vector-align-1.c:11:6: unsupported alignment 128 of char (decl.go:296:externalDeclaration: decl.go:606:declaration: decl.go:775:initDeclarator: type.go:42:typ: type.go:65:typ0: type.go:441:isValidTyp..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/20020411-1.c`:                     {}, // COMPILE FAIL: "\"TODO UnaryExpressionReal (expr.go:101:expr: expr.go:494:expr0: expr.go:3439:assignmentExpression: expr.go:101:expr: expr.go:530:expr0: expr.go:1717:unaryExpression:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/20030330-1.c`:                     {}, // COMPILE FAIL: "20030330-1.o.go:26:4: undefined: \"link_error\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:) (all_test.go:444:1: all_t..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/20040302-1.c`:                     {}, // COMPILE FAIL: "\"TODO <nil> (asm_amd64.s:1650:goexit: compile.go:433:compile: decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:344:functionDefinition0: decl.go:101:newFnCtx:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/20041201-1.c`:                     {}, // COMPILE FAIL: "\"TODO *cc.PredefinedType _Complex char _Complex char (decl.go:296:externalDeclaration: decl.go:606:declaration: decl.go:745:initDeclarator: type.go:18:typedef: type.go:263:typ0: type.go:159:typ0:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/20041214-1.c`:                     {}, // COMPILE FAIL: "\"TODO <nil> (asm_amd64.s:1650:goexit: compile.go:433:compile: decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:344:functionDefinition0: decl.go:101:newFnCtx:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/20050121-1.c`:                     {}, // COMPILE FAIL: "\"TODO UnaryExpressionReal (expr.go:101:expr: expr.go:494:expr0: expr.go:3439:assignmentExpression: expr.go:101:expr: expr.go:530:expr0: expr.go:1717:unaryExpression:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/20050316-1.c`:                     {}, // COMPILE FAIL: "20050316-1.o.go:17:17: undefined: \"main\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:) (all_test.go:444:1: all_test.g..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/20050316-2.c`:                     {}, // COMPILE FAIL: "20050316-2.o.go:17:17: undefined: \"main\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:) (all_test.go:444:1: all_test.g..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/20050316-3.c`:                     {}, // COMPILE FAIL: "20050316-3.o.go:17:17: undefined: \"main\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:) (all_test.go:444:1: all_test.g..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/20050604-1.c`:                     {}, // COMPILE FAIL: "\"20050604-1.c:16:3: unsupported vector type: v4hi (decl.go:606:declaration: decl.go:775:initDeclarator: type.go:42:typ: type.go:338:typ0: type.go:65:typ0: type.go:455:isValidType1:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/20050607-1.c`:                     {}, // COMPILE FAIL: "20050607-1.o.go:17:17: undefined: \"main\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:) (all_test.go:444:1: all_test.g..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/20060420-1.c`:                     {}, // COMPILE FAIL: "20060420-1.o.go:26:17: undefined: \"main\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:) (all_test.go:444:1: all_test.g..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/20071210-1.c`:                     {}, // COMPILE FAIL: "\"TODO <nil> (asm_amd64.s:1650:goexit: compile.go:433:compile: decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:344:functionDefinition0: decl.go:101:newFnCtx:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/20171008-1.c`:                     {}, // COMPILE FAIL: "\"20171008-1.c:16:1: unsupported alignment 4 of function(void) returning struct S (asm_amd64.s:1650:goexit: compile.go:433:compile: decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/comp-goto-1.c`:                    {}, // COMPILE FAIL: "\"TODO <nil> (asm_amd64.s:1650:goexit: compile.go:433:compile: decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:344:functionDefinition0: decl.go:101:newFnCtx:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/complex-6.c`:                      {}, // COMPILE FAIL: "\"TODO *cc.PredefinedType _Complex int _Complex int (decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:381:functionDefinition0: decl.go:549:signature: type.go:48:typ2: type.go:15..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/complex-7.c`:                      {}, // COMPILE FAIL: "\"TODO 2.2iL *cc.ComplexLongDoubleValue from=_Complex long t=long double mode=exprDefault (expr.go:1193:binopArgs: expr.go:1198:checkVolatileExpr: expr.go:101:expr: expr.go:524:expr0: expr.go:3817:prim..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/fprintf-2.c`:                      {}, // COMPILE FAIL: "fprintf-2.o.go:1723:15: undefined: \"tmpnam\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:)"
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/ieee/mzero4.c`:                    {}, // COMPILE FAIL: "mzero4.o.go:51:18: undefined: \"tanf\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:)"
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/ieee/pr72824-2.c`:                 {}, // COMPILE FAIL: "pr72824-2.o.go:17:17: undefined: \"main\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:) (all_test.go:444:1: all_test.go..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr23135.c`:                        {}, // COMPILE FAIL: "\"pr23135.c:19:14: unsupported vector type: vecint (expr.go:524:expr0: expr.go:3815:primaryExpression: expr.go:4235:primaryExpressionIntConst: type.go:60:verifyTyp: type.go:65:typ0: type.go:455:isValid..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr23324.c`:                        {}, // COMPILE FAIL: "\"TODO (decl.go:830:initDeclarator: type.go:657:defineType: type.go:671:defineType0: type.go:593:defineUnionType: type.go:503:unionLiteral: type.go:325:typ0:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr34154.c`:                        {}, // COMPILE FAIL: "\"TODO SelectionStatementSwitch (decl.go:352:functionDefinition0: stmt.go:324:compoundStatement: stmt.go:360:blockItem: stmt.go:42:statement: stmt.go:444:selectionStatement: stmt.go:512:selectionStatem..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr36093.c`:                        {}, // COMPILE FAIL: "\"pr36093.c:13:5: unsupported alignment 128 of Foo (decl.go:606:declaration: decl.go:775:initDeclarator: type.go:42:typ: type.go:352:typ0: type.go:65:typ0: type.go:441:isValidType1:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr38151.c`:                        {}, // COMPILE FAIL: "\"TODO *cc.PredefinedType _Complex int _Complex int (decl.go:296:externalDeclaration: decl.go:596:declaration: type.go:574:defineStructType: type.go:509:structLiteral: type.go:263:typ0: type.go:159:typ..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr43783.c`:                        {}, // COMPILE FAIL: "\"pr43783.c:8:9: unsupported alignment 16 of UINT192 (decl.go:606:declaration: decl.go:775:initDeclarator: type.go:42:typ: type.go:352:typ0: type.go:65:typ0: type.go:441:isValidType1:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr49218.c`:                        {}, // COMPILE FAIL: "\"pr49218.c:11:9: unsupported alignment 16 of L (expr.go:101:expr: expr.go:524:expr0: expr.go:3726:primaryExpression: type.go:60:verifyTyp: type.go:65:typ0: type.go:441:isValidType1:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr53645-2.c`:                      {}, // COMPILE FAIL: "\"pr53645-2.c:44:3: unsupported vector type: UV (init.go:110:initializer: init.go:193:initializerArray: type.go:42:typ: type.go:352:typ0: type.go:65:typ0: type.go:455:isValidType1:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr53645.c`:                        {}, // COMPILE FAIL: "\"pr53645.c:44:3: unsupported vector type: UV (init.go:110:initializer: init.go:193:initializerArray: type.go:42:typ: type.go:352:typ0: type.go:65:typ0: type.go:455:isValidType1:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr54471.c`:                        {}, // COMPILE FAIL: "\"pr54471.c:13:1: unsupported alignment 16 of unsigned __int128 (decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:342:functionDefinition0: type.go:469:isValidType1: type.go:422:..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr56837.c`:                        {}, // COMPILE FAIL: "\"TODO *cc.PredefinedType _Complex int _Complex int (decl.go:296:externalDeclaration: decl.go:606:declaration: decl.go:775:initDeclarator: type.go:42:typ: type.go:352:typ0: type.go:159:typ0:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr60960.c`:                        {}, // COMPILE FAIL: "pr60960.o.go:17:17: undefined: \"main\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:) (all_test.go:444:1: all_test.go:5..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr61375.c`:                        {}, // COMPILE FAIL: "\"pr61375.c:15:1: unsupported alignment 16 of unsigned __int128 (decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:342:functionDefinition0: type.go:474:isValidType1: type.go:398:..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr63302.c`:                        {}, // COMPILE FAIL: "\"pr63302.c:14:1: unsupported alignment 16 of __int128 (decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:342:functionDefinition0: type.go:474:isValidType1: type.go:398:isValidPa..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr65170.c`:                        {}, // COMPILE FAIL: "\"pr65170.c:12:1: unsupported alignment 16 of V (decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:342:functionDefinition0: type.go:474:isValidType1: type.go:398:isValidParamType..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr65427.c`:                        {}, // COMPILE FAIL: "\"pr65427.c:4:3: unsupported vector type: V (decl.go:296:externalDeclaration: decl.go:606:declaration: decl.go:775:initDeclarator: type.go:42:typ: type.go:65:typ0: type.go:455:isValidType1:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr68249.c`:                        {}, // COMPILE FAIL: "\"-: TODO (expr.go:3444:assignmentExpression: expr.go:101:expr: expr.go:506:expr0: expr.go:914:conditionalExpression: expr.go:70:topExpr: expr.go:85:expr:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr68381.c`:                        {}, // COMPILE FAIL: "\"TODO unsigned short * unsigned short -> int (stmt.go:42:statement: stmt.go:391:selectionStatement: expr.go:101:expr: expr.go:522:expr0: expr.go:2007:postfixExpression: expr.go:2245:mulOverflow:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr70460.c`:                        {}, // COMPILE FAIL: "\"TODO <nil> (asm_amd64.s:1650:goexit: compile.go:433:compile: decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:344:functionDefinition0: decl.go:101:newFnCtx:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr70903.c`:                        {}, // COMPILE FAIL: "pr70903.o.go:17:17: undefined: \"main\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:) (all_test.go:444:1: all_test.go:5..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr71554.c`:                        {}, // COMPILE FAIL: "\"TODO unsigned * int -> int (stmt.go:42:statement: stmt.go:391:selectionStatement: expr.go:101:expr: expr.go:522:expr0: expr.go:2007:postfixExpression: expr.go:2245:mulOverflow:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr71626-1.c`:                      {}, // COMPILE FAIL: "pr71626-1.o.go:17:17: undefined: \"main\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:) (all_test.go:444:1: all_test.go..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr71626-2.c`:                      {}, // COMPILE FAIL: "pr71626-2.o.go:17:17: undefined: \"main\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:) (all_test.go:444:1: all_test.go..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr77767.c`:                        {}, // COMPILE FAIL: "\"pr77767.c:4:1: incomplete type: array of int (decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:342:functionDefinition0: type.go:474:isValidType1: type.go:398:isValidParamType:..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr84169.c`:                        {}, // COMPILE FAIL: "\"pr84169.c:9:3: unsupported alignment 16 of T (decl.go:296:externalDeclaration: decl.go:606:declaration: decl.go:775:initDeclarator: type.go:42:typ: type.go:65:typ0: type.go:441:isValidType1:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr84748.c`:                        {}, // COMPILE FAIL: "\"pr84748.c:6:6: unsupported alignment 16 of u128 (decl.go:296:externalDeclaration: decl.go:606:declaration: decl.go:775:initDeclarator: type.go:42:typ: type.go:65:typ0: type.go:441:isValidType1:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr85169.c`:                        {}, // COMPILE FAIL: "pr85169.o.go:17:17: undefined: \"main\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:) (all_test.go:444:1: all_test.go:5..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr85582-2.c`:                      {}, // COMPILE FAIL: "\"pr85582-2.c:12:1: unsupported alignment 16 of S (decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:342:functionDefinition0: type.go:469:isValidType1: type.go:422:isValidType: t..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr85582-3.c`:                      {}, // COMPILE FAIL: "\"pr85582-3.c:12:1: unsupported alignment 16 of U (decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:342:functionDefinition0: type.go:469:isValidType1: type.go:422:isValidType: t..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr88739.c`:                        {}, // COMPILE FAIL: "\"TODO exprUintptr (expr.go:2028:postfixExpression: expr.go:2564:postfixExpressionSelect: expr.go:101:expr: expr.go:522:expr0: expr.go:2028:postfixExpression: expr.go:2663:postfixExpressionSelect:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/pr89434.c`:                        {}, // COMPILE FAIL: "\"TODO int * long -> unsigned (stmt.go:38:statement: expr.go:70:topExpr: expr.go:101:expr: expr.go:522:expr0: expr.go:2007:postfixExpression: expr.go:2245:mulOverflow:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/printf-2.c`:                       {}, // COMPILE FAIL: "printf-2.o.go:1736:15: undefined: \"tmpnam\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:)"
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/scal-to-vec1.c`:                   {}, // COMPILE FAIL: "\"scal-to-vec1.c:34:28: unsupported vector type: short (expr.go:115:expr: expr.go:169:convert: expr.go:329:convertType: type.go:60:verifyTyp: type.go:65:typ0: type.go:455:isValidType1:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/scal-to-vec2.c`:                   {}, // COMPILE FAIL: "\"scal-to-vec2.c:35:28: unsupported vector type: char (expr.go:101:expr: expr.go:524:expr0: expr.go:3726:primaryExpression: type.go:60:verifyTyp: type.go:65:typ0: type.go:455:isValidType1:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/scal-to-vec3.c`:                   {}, // COMPILE FAIL: "\"scal-to-vec3.c:20:28: unsupported vector type: float (expr.go:524:expr0: expr.go:3817:primaryExpression: expr.go:4273:primaryExpressionFloatConst: type.go:60:verifyTyp: type.go:65:typ0: type.go:455:i..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/simd-6.c`:                         {}, // COMPILE FAIL: "simd-6.o.go:17:17: undefined: \"main\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:) (all_test.go:444:1: all_test.go:53..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/string-opt-18.c`:                  {}, // COMPILE FAIL: "string-opt-18.o.go:27:5: undefined: \"mempcpy\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:) (all_test.go:444:1: all_t..."
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/user-printf.c`:                    {}, // COMPILE FAIL: "user-printf.o.go:1734:15: undefined: \"tmpnam\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:)"
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/execute/zero-struct-2.c`:                  {}, // COMPILE FAIL: "\"zero-struct-2.c:15:48: TODO \\\"Xone_raw_spinlock(cgtls)\\\" raw_spinlock_t, 0 exprDefault -> spinlock_t, 0 exprDefault (zero-struct-2.c:15:48:) (expr.go:522:expr0: expr.go:2206:postfixExpression: init.g..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/20020411-1.c`:     {}, // COMPILE FAIL: "\"TODO UnaryExpressionReal (expr.go:101:expr: expr.go:494:expr0: expr.go:3439:assignmentExpression: expr.go:101:expr: expr.go:530:expr0: expr.go:1717:unaryExpression:)\""
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/20030330-1.c`:     {}, // COMPILE FAIL: "20030330-1.o.go:26:4: undefined: \"link_error\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:) (all_test.go:444:1: all_t..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/20040302-1.c`:     {}, // COMPILE FAIL: "\"TODO <nil> (asm_amd64.s:1650:goexit: compile.go:433:compile: decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:344:functionDefinition0: decl.go:101:newFnCtx:)\""
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/20041201-1.c`:     {}, // COMPILE FAIL: "\"TODO *cc.PredefinedType _Complex char _Complex char (decl.go:296:externalDeclaration: decl.go:606:declaration: decl.go:745:initDeclarator: type.go:18:typedef: type.go:263:typ0: type.go:159:typ0:)\""
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/20041214-1.c`:     {}, // COMPILE FAIL: "\"TODO <nil> (asm_amd64.s:1650:goexit: compile.go:433:compile: decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:344:functionDefinition0: decl.go:101:newFnCtx:)\""
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/20050121-1.c`:     {}, // COMPILE FAIL: "\"TODO UnaryExpressionReal (expr.go:101:expr: expr.go:494:expr0: expr.go:3439:assignmentExpression: expr.go:101:expr: expr.go:530:expr0: expr.go:1717:unaryExpression:)\""
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/20050316-1.c`:     {}, // COMPILE FAIL: "20050316-1.o.go:17:17: undefined: \"main\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:) (all_test.go:444:1: all_test.g..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/20050316-2.c`:     {}, // COMPILE FAIL: "20050316-2.o.go:17:17: undefined: \"main\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:) (all_test.go:444:1: all_test.g..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/20050316-3.c`:     {}, // COMPILE FAIL: "20050316-3.o.go:17:17: undefined: \"main\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:) (all_test.go:444:1: all_test.g..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/20050604-1.c`:     {}, // COMPILE FAIL: "\"20050604-1.c:16:3: unsupported vector type: v4hi (decl.go:606:declaration: decl.go:775:initDeclarator: type.go:42:typ: type.go:338:typ0: type.go:65:typ0: type.go:455:isValidType1:)\""
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/20050607-1.c`:     {}, // COMPILE FAIL: "20050607-1.o.go:17:17: undefined: \"main\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:) (all_test.go:444:1: all_test.g..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/20060420-1.c`:     {}, // COMPILE FAIL: "20060420-1.o.go:26:17: undefined: \"main\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:) (all_test.go:444:1: all_test.g..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/20071210-1.c`:     {}, // COMPILE FAIL: "\"TODO <nil> (asm_amd64.s:1650:goexit: compile.go:433:compile: decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:344:functionDefinition0: decl.go:101:newFnCtx:)\""
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/20171008-1.c`:     {}, // COMPILE FAIL: "\"20171008-1.c:16:1: unsupported alignment 4 of function(void) returning struct S (asm_amd64.s:1650:goexit: compile.go:433:compile: decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/comp-goto-1.c`:    {}, // COMPILE FAIL: "\"TODO <nil> (asm_amd64.s:1650:goexit: compile.go:433:compile: decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:344:functionDefinition0: decl.go:101:newFnCtx:)\""
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/complex-6.c`:      {}, // COMPILE FAIL: "\"TODO *cc.PredefinedType _Complex int _Complex int (decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:381:functionDefinition0: decl.go:549:signature: type.go:48:typ2: type.go:15..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/complex-7.c`:      {}, // COMPILE FAIL: "\"TODO 2.2iL *cc.ComplexLongDoubleValue from=_Complex long t=long double mode=exprDefault (expr.go:1193:binopArgs: expr.go:1198:checkVolatileExpr: expr.go:101:expr: expr.go:524:expr0: expr.go:3817:prim..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/fprintf-2.c`:      {}, // COMPILE FAIL: "fprintf-2.o.go:1723:15: undefined: \"tmpnam\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:)"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/ieee/mzero4.c`:    {}, // COMPILE FAIL: "mzero4.o.go:51:18: undefined: \"tanf\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:)"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/ieee/pr72824-2.c`: {}, // COMPILE FAIL: "pr72824-2.o.go:17:17: undefined: \"main\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:) (all_test.go:444:1: all_test.go..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr23135.c`:        {}, // COMPILE FAIL: "\"pr23135.c:19:14: unsupported vector type: vecint (expr.go:524:expr0: expr.go:3815:primaryExpression: expr.go:4235:primaryExpressionIntConst: type.go:60:verifyTyp: type.go:65:typ0: type.go:455:isValid..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr23324.c`:        {}, // COMPILE FAIL: "\"TODO (decl.go:830:initDeclarator: type.go:657:defineType: type.go:671:defineType0: type.go:593:defineUnionType: type.go:503:unionLiteral: type.go:325:typ0:)\""
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr34154.c`:        {}, // COMPILE FAIL: "\"TODO SelectionStatementSwitch (decl.go:352:functionDefinition0: stmt.go:324:compoundStatement: stmt.go:360:blockItem: stmt.go:42:statement: stmt.go:444:selectionStatement: stmt.go:512:selectionStatem..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr38151.c`:        {}, // COMPILE FAIL: "\"TODO *cc.PredefinedType _Complex int _Complex int (decl.go:296:externalDeclaration: decl.go:596:declaration: type.go:574:defineStructType: type.go:509:structLiteral: type.go:263:typ0: type.go:159:typ..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr49218.c`:        {}, // COMPILE FAIL: "\"pr49218.c:11:9: unsupported alignment 16 of L (expr.go:101:expr: expr.go:524:expr0: expr.go:3726:primaryExpression: type.go:60:verifyTyp: type.go:65:typ0: type.go:441:isValidType1:)\""
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr53645-2.c`:      {}, // COMPILE FAIL: "\"pr53645-2.c:44:3: unsupported vector type: UV (init.go:110:initializer: init.go:193:initializerArray: type.go:42:typ: type.go:352:typ0: type.go:65:typ0: type.go:455:isValidType1:)\""
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr53645.c`:        {}, // COMPILE FAIL: "\"pr53645.c:44:3: unsupported vector type: UV (init.go:110:initializer: init.go:193:initializerArray: type.go:42:typ: type.go:352:typ0: type.go:65:typ0: type.go:455:isValidType1:)\""
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr54471.c`:        {}, // COMPILE FAIL: "\"pr54471.c:13:1: unsupported alignment 16 of unsigned __int128 (decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:342:functionDefinition0: type.go:469:isValidType1: type.go:422:..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr56837.c`:        {}, // COMPILE FAIL: "\"TODO *cc.PredefinedType _Complex int _Complex int (decl.go:296:externalDeclaration: decl.go:606:declaration: decl.go:775:initDeclarator: type.go:42:typ: type.go:352:typ0: type.go:159:typ0:)\""
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr60960.c`:        {}, // COMPILE FAIL: "pr60960.o.go:17:17: undefined: \"main\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:) (all_test.go:444:1: all_test.go:5..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr61375.c`:        {}, // COMPILE FAIL: "\"pr61375.c:15:1: unsupported alignment 16 of unsigned __int128 (decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:342:functionDefinition0: type.go:474:isValidType1: type.go:398:..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr63302.c`:        {}, // COMPILE FAIL: "\"pr63302.c:14:1: unsupported alignment 16 of __int128 (decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:342:functionDefinition0: type.go:474:isValidType1: type.go:398:isValidPa..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr65170.c`:        {}, // COMPILE FAIL: "\"pr65170.c:12:1: unsupported alignment 16 of V (decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:342:functionDefinition0: type.go:474:isValidType1: type.go:398:isValidParamType..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr65427.c`:        {}, // COMPILE FAIL: "\"pr65427.c:4:3: unsupported vector type: V (decl.go:296:externalDeclaration: decl.go:606:declaration: decl.go:775:initDeclarator: type.go:42:typ: type.go:65:typ0: type.go:455:isValidType1:)\""
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr68249.c`:        {}, // COMPILE FAIL: "\"-: TODO (expr.go:3444:assignmentExpression: expr.go:101:expr: expr.go:506:expr0: expr.go:914:conditionalExpression: expr.go:70:topExpr: expr.go:85:expr:)\""
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr68381.c`:        {}, // COMPILE FAIL: "\"TODO unsigned short * unsigned short -> int (stmt.go:42:statement: stmt.go:391:selectionStatement: expr.go:101:expr: expr.go:522:expr0: expr.go:2007:postfixExpression: expr.go:2245:mulOverflow:)\""
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr70460.c`:        {}, // COMPILE FAIL: "\"TODO <nil> (asm_amd64.s:1650:goexit: compile.go:433:compile: decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:344:functionDefinition0: decl.go:101:newFnCtx:)\""
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr70903.c`:        {}, // COMPILE FAIL: "pr70903.o.go:17:17: undefined: \"main\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:) (all_test.go:444:1: all_test.go:5..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr71554.c`:        {}, // COMPILE FAIL: "\"TODO unsigned * int -> int (stmt.go:42:statement: stmt.go:391:selectionStatement: expr.go:101:expr: expr.go:522:expr0: expr.go:2007:postfixExpression: expr.go:2245:mulOverflow:)\""
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr71626-1.c`:      {}, // COMPILE FAIL: "pr71626-1.o.go:17:17: undefined: \"main\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:) (all_test.go:444:1: all_test.go..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr71626-2.c`:      {}, // COMPILE FAIL: "pr71626-2.o.go:17:17: undefined: \"main\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:) (all_test.go:444:1: all_test.go..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr77767.c`:        {}, // COMPILE FAIL: "\"pr77767.c:4:1: incomplete type: array of int (decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:342:functionDefinition0: type.go:474:isValidType1: type.go:398:isValidParamType:..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr84169.c`:        {}, // COMPILE FAIL: "\"pr84169.c:9:3: unsupported alignment 16 of T (decl.go:296:externalDeclaration: decl.go:606:declaration: decl.go:775:initDeclarator: type.go:42:typ: type.go:65:typ0: type.go:441:isValidType1:)\""
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr84748.c`:        {}, // COMPILE FAIL: "\"pr84748.c:6:6: unsupported alignment 16 of u128 (decl.go:296:externalDeclaration: decl.go:606:declaration: decl.go:775:initDeclarator: type.go:42:typ: type.go:65:typ0: type.go:441:isValidType1:)\""
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr85169.c`:        {}, // COMPILE FAIL: "pr85169.o.go:17:17: undefined: \"main\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:) (all_test.go:444:1: all_test.go:5..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr85582-2.c`:      {}, // COMPILE FAIL: "\"pr85582-2.c:12:1: unsupported alignment 16 of S (decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:342:functionDefinition0: type.go:469:isValidType1: type.go:422:isValidType: t..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr85582-3.c`:      {}, // COMPILE FAIL: "\"pr85582-3.c:12:1: unsupported alignment 16 of U (decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:342:functionDefinition0: type.go:469:isValidType1: type.go:422:isValidType: t..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr88739.c`:        {}, // COMPILE FAIL: "\"TODO exprUintptr (expr.go:2028:postfixExpression: expr.go:2564:postfixExpressionSelect: expr.go:101:expr: expr.go:522:expr0: expr.go:2028:postfixExpression: expr.go:2663:postfixExpressionSelect:)\""
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr89434.c`:        {}, // COMPILE FAIL: "\"TODO int * long -> unsigned (stmt.go:38:statement: expr.go:70:topExpr: expr.go:101:expr: expr.go:522:expr0: expr.go:2007:postfixExpression: expr.go:2245:mulOverflow:)\""
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr90311.c`:        {}, // COMPILE FAIL: "\"TODO unsigned char + int -> unsigned (stmt.go:38:statement: expr.go:70:topExpr: expr.go:101:expr: expr.go:522:expr0: expr.go:2009:postfixExpression: expr.go:2296:addOverflow:)\""
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr91450-1.c`:      {}, // COMPILE FAIL: "\"TODO int * int -> unsigned long long (expr.go:1638:unaryExpression: expr.go:1198:checkVolatileExpr: expr.go:101:expr: expr.go:522:expr0: expr.go:2007:postfixExpression: expr.go:2245:mulOverflow:)\""
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr91450-2.c`:      {}, // COMPILE FAIL: "\"TODO int * int -> unsigned long long (stmt.go:42:statement: stmt.go:391:selectionStatement: expr.go:101:expr: expr.go:522:expr0: expr.go:2007:postfixExpression: expr.go:2245:mulOverflow:)\""
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr91635.c`:        {}, // COMPILE FAIL: "\"TODO int + int -> unsigned short (expr.go:494:expr0: expr.go:3559:assignmentExpression: expr.go:101:expr: expr.go:522:expr0: expr.go:2009:postfixExpression: expr.go:2296:addOverflow:)\""
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr92618.c`:        {}, // COMPILE FAIL: "pr92618.o.go:31:17: undefined: \"main\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:) (all_test.go:444:1: all_test.go:5..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr92904.c`:        {}, // COMPILE FAIL: "\"pr92904.c:12:10: unsupported alignment 16 of __int128 (decl.go:296:externalDeclaration: decl.go:606:declaration: decl.go:775:initDeclarator: type.go:42:typ: type.go:65:typ0: type.go:441:isValidType1:..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr93213.c`:        {}, // COMPILE FAIL: "\"pr93213.c:11:1: unsupported alignment 16 of u128 (decl.go:294:externalDeclaration: decl.go:322:functionDefinition: decl.go:342:functionDefinition0: type.go:469:isValidType1: type.go:422:isValidType: ..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr93434.c`:        {}, // COMPILE FAIL: "\"TODO \\\"(!(((aai) != 0)))\\\" int exprBool -> double exprDefault (expr.go:508:expr0: expr.go:1269:equalityExpression: expr.go:1193:binopArgs: expr.go:1198:checkVolatileExpr: expr.go:115:expr: expr.go:18..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr94412.c`:        {}, // COMPILE FAIL: "pr94412.o.go:19:17: undefined: \"main\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:) (all_test.go:444:1: all_test.go:5..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr94524-1.c`:      {}, // COMPILE FAIL: "pr94524-1.o.go:17:17: undefined: \"main\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:) (all_test.go:444:1: all_test.go..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr94524-2.c`:      {}, // COMPILE FAIL: "pr94524-2.o.go:17:17: undefined: \"main\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:) (all_test.go:444:1: all_test.go..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/pr98474.c`:        {}, // COMPILE FAIL: "\"pr98474.c:14:3: unsupported alignment 16 of T (expr.go:101:expr: expr.go:494:expr0: expr.go:3576:assignmentExpression: type.go:42:typ: type.go:65:typ0: type.go:441:isValidType1:)\""
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/printf-2.c`:       {}, // COMPILE FAIL: "printf-2.o.go:1736:15: undefined: \"tmpnam\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:)"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/scal-to-vec1.c`:   {}, // COMPILE FAIL: "\"scal-to-vec1.c:34:28: unsupported vector type: short (expr.go:115:expr: expr.go:169:convert: expr.go:329:convertType: type.go:60:verifyTyp: type.go:65:typ0: type.go:455:isValidType1:)\""
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/scal-to-vec2.c`:   {}, // COMPILE FAIL: "\"scal-to-vec2.c:35:28: unsupported vector type: char (expr.go:101:expr: expr.go:524:expr0: expr.go:3726:primaryExpression: type.go:60:verifyTyp: type.go:65:typ0: type.go:455:isValidType1:)\""
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/scal-to-vec3.c`:   {}, // COMPILE FAIL: "\"scal-to-vec3.c:20:28: unsupported vector type: float (expr.go:524:expr0: expr.go:3817:primaryExpression: expr.go:4273:primaryExpressionFloatConst: type.go:60:verifyTyp: type.go:65:typ0: type.go:455:i..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/simd-6.c`:         {}, // COMPILE FAIL: "simd-6.o.go:17:17: undefined: \"main\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:) (all_test.go:444:1: all_test.go:53..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/string-opt-18.c`:  {}, // COMPILE FAIL: "string-opt-18.o.go:27:5: undefined: \"mempcpy\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:) (all_test.go:444:1: all_t..."
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/user-printf.c`:    {}, // COMPILE FAIL: "user-printf.o.go:1734:15: undefined: \"tmpnam\" external (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:302:link: link.go:814:link:)"
	`assets/github.com/gcc-mirror/gcc/gcc/testsuite/gcc.c-torture/execute/zero-struct-2.c`:  {}, // COMPILE FAIL: "\"zero-struct-2.c:15:48: TODO \\\"Xone_raw_spinlock(cgtls)\\\" raw_spinlock_t, 0 exprDefault -> spinlock_t, 0 exprDefault (zero-struct-2.c:15:48:) (expr.go:522:expr0: expr.go:2206:postfixExpression: init.g..."
	`assets/github.com/vnmakarov/mir/c-tests/lacc/deref-compare-float.c`:                    {}, // COMPILE FAIL: "\"TODO \\\"((iqlibc.ppFloat64FromFloat64(0)) > (ppfloat64((*(*ppint32)(iqunsafe.ppPointer((Xi)))))))\\\" int exprBool -> float exprDefault (expr.go:70:topExpr: expr.go:101:expr: expr.go:494:expr0: expr.go:..."
	`assets/github.com/vnmakarov/mir/c-tests/lacc/float-compare-equal.c`:                    {}, // COMPILE FAIL: "\"TODO \\\"((ppfloat32((ppfloat32(Xi)))) == (*(*ppfloat32)(iqunsafe.ppPointer((Xf)))))\\\" int exprBool -> float exprDefault (expr.go:70:topExpr: expr.go:101:expr: expr.go:494:expr0: expr.go:3444:assignmen..."
	`assets/github.com/vnmakarov/mir/c-tests/lacc/function-incomplete.c`:                    {}, // COMPILE FAIL: "\"function-incomplete.c:6:9: too few arguments to function 'foo', type 'function(pointer to char) returning int' in 'foo()' (expr.go:1193:binopArgs: expr.go:1198:checkVolatileExpr: expr.go:101:expr: ex..."
	`assets/github.com/vnmakarov/mir/c-tests/lacc/identifier.c`:                             {}, // COMPILE FAIL: "invalid object file: multiple defintions of c (all_test.go:444:1: all_test.go:530:testExec1: ccgo.go:192:Main: ccgo.go:581:main: link.go:260:link: link.go:520:getFileSymbols:)"
	`assets/github.com/vnmakarov/mir/c-tests/lacc/initialize-call.c`:                        {}, // COMPILE FAIL: "\"initialize-call.c:25:9: TODO \\\"sigetobj(cgtls, (ppint32(2)), (ppint32(8)), (ppint32(1)))\\\" struct obj {s array of 3 short}, 6 exprDefault -> struct {t struct obj}, 6 exprDefault (initialize-call.c:25..."
	`assets/github.com/vnmakarov/mir/c-tests/lacc/initialize-string.c`:                      {}, // COMPILE FAIL: "\"initialize-string.c:14:14: TODO \\\"\\\\\\\"wat\\\\\\\\x00\\\\\\\"\\\" pointer to char, 8 exprDefault -> array of 7 char, 7 exprDefault (initialize-string.c:14:14:) (decl.go:898:initDeclarator: init.go:32:initialize..."
	`assets/github.com/vnmakarov/mir/c-tests/lacc/string-addr.c`:                            {}, // COMPILE FAIL: "\"string-addr.c:4:16: TODO array of 6 char pointer to array of 6 char pointer to array of 6 char \\\"Hello\\\\x00\\\" (expr.go:530:expr0: expr.go:1557:unaryExpression: expr.go:101:expr: expr.go:524:expr0: ex..."
	`assets/github.com/vnmakarov/mir/c-tests/lacc/stringify.c`:                              {}, // COMPILE FAIL: "\"TODO `'\\\\xA'` -> invalid syntax (expr.go:3557:assignmentExpression: expr.go:70:topExpr: expr.go:101:expr: expr.go:524:expr0: expr.go:3819:primaryExpression: expr.go:4088:primaryExpressionCharConst:)\""
	`assets/tcc-0.9.27/tests/tests2/76_dollars_in_identifiers.c`:                            {}, // COMPILE FAIL: "\"76_dollars_in_identifiers.c: gofmt: exit status 2 (.:0:: asm_amd64.s:1650:goexit: asm_amd64.s:1650:goexit: asm_amd64.s:1650:goexit: compile.go:495:compile: compile.go:495:compile:)\""
	`assets/tcc-0.9.27/tests/tests2/87_dead_code.c`:                                         {}, // COMPILE FAIL: "\"87_dead_code.c: gofmt: exit status 2 (.:0:: asm_amd64.s:1650:goexit: asm_amd64.s:1650:goexit: asm_amd64.s:1650:goexit: compile.go:495:compile: compile.go:495:compile:)\""
	`assets/tcc-0.9.27/tests/tests2/95_bitfields.c`:                                         {}, // COMPILE FAIL: "\"95_bitfields.c:27:5: unsupported alignment 16 of char (expr.go:101:expr: expr.go:530:expr0: expr.go:1658:unaryExpression: type.go:410:isValidType: type.go:422:isValidType: type.go:441:isValidType1:)\""
	`assets/tcc-0.9.27/tests/tests2/95_bitfields_ms.c`:                                      {}, // COMPILE FAIL: "\"95_bitfields.c:27:5: unsupported alignment 16 of char (expr.go:101:expr: expr.go:530:expr0: expr.go:1658:unaryExpression: type.go:410:isValidType: type.go:422:isValidType: type.go:441:isValidType1:)\""
	`assets/gcc-9.1.0/gcc/testsuite/gcc.c-torture/compile/pr70355.c`:                        {}, // COMPILE FAIL: "\"TODO vector (compile.go:433:compile: decl.go:296:externalDeclaration: decl.go:606:declaration: decl.go:745:initDeclarator: type.go:18:typedef: type.go:89:typ0:)\""
}
